@@ -1,6 +1,6 @@
 ;;; Consfigurator -- Lisp declarative configuration management system
 
-;;; Copyright (C) 2020-2021  Sean Whitton <spwhitton@spwhitton.name>
+;;; Copyright (C) 2020-2022  Sean Whitton <spwhitton@spwhitton.name>
 
 ;;; This file is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -58,27 +58,24 @@
 (defun proppp (prop)
   (get prop 'preprocess (lambda (&rest args) args)))
 
-(defun propapptype (propapp)
+(defun propapp-type (propapp)
   (if propapp
       (get (car propapp) 'ptype)
       :posix))
 
-(defun propappargs (propapp)
+(defun propapp-args (propapp)
   (if (and (listp (cadr propapp)) (member :orig-args (cadr propapp)))
       (getf (cadr propapp) :orig-args)
       (cdr propapp)))
 
-(defun collapse-types (&rest lists)
-  (if (member :lisp (flatten lists)) :lisp :posix))
-
-(defun collapse-propapp-types (&rest lists)
-  (if (member :lisp (mapcan (curry #'mapcar #'propapptype) lists))
+(defun combine-propapp-types (&rest lists)
+  (if (member :lisp (mapcan (curry #'mapcar #'propapp-type) lists))
       :lisp :posix))
 
 (defun propdesc (prop &rest args)
-  (apply (get prop 'desc #'noop) args))
+  (apply (get prop 'desc (lambda-ignoring-args)) args))
 
-(defun propappdesc (propapp)
+(defun propapp-desc (propapp)
   (when propapp
     (apply #'propdesc propapp)))
 
@@ -86,16 +83,16 @@
   (get prop 'plambda))
 
 (defun propattrs (prop &rest args)
-  (apply (get prop 'hostattrs #'noop) args))
+  (apply (get prop 'hostattrs (lambda-ignoring-args)) args))
 
-(defun propappattrs (propapp)
+(defun propapp-attrs (propapp)
   (when propapp
     (apply #'propattrs propapp)))
 
 (defun propcheck (prop &rest args)
-  (apply (get prop 'check #'noop) args))
+  (apply (get prop 'check (lambda-ignoring-args)) args))
 
-(defun propappcheck (propapp)
+(defun check-propapp (propapp)
   (if propapp (apply #'propcheck propapp) t))
 
 (defmacro with-some-errors-are-failed-change (&body forms)
@@ -109,7 +106,7 @@
         :no-change
         (apply (get prop 'papply (constantly :no-change)) args))))
 
-(defun propappapply (propapp)
+(defun apply-propapp (propapp)
   (if propapp
       (apply #'propapply propapp)
       :no-change))
@@ -133,7 +130,7 @@
          (failed-change
 "Attempt to unapply property with :APPLY subroutine but no :UNAPPLY subroutine."))))))
 
-(defun propappunapply (propapp)
+(defun unapply-propapp (propapp)
   (if propapp
       (apply #'propunapply propapp)
       :no-change))
@@ -413,11 +410,11 @@ You can usually use DEFPROPLIST instead of DEFPROPSPEC, which see."
   (setf (getf slots :apply)
         '(lambda (plist)
           (let ((propapp (eval-propspec (getf plist :propspec))))
-            (assert-connection-supports (propapptype propapp))
-            (propappapply propapp))))
+            (assert-connection-supports (propapp-type propapp))
+            (apply-propapp propapp))))
   (setf (getf slots :unapply)
         '(lambda (plist)
-          (propappunapply (eval-propspec (getf plist :propspec)))))
+          (unapply-propapp (eval-propspec (getf plist :propspec)))))
   (loop while (and (listp (car forms)) (keywordp (caar forms)))
 	do (setf (getf slots (caar forms))
 		 `(lambda (plist)
@@ -441,7 +438,7 @@ You can usually use DEFPROPLIST instead of DEFPROPSPEC, which see."
                                                (getf plist :orig-args)
                                              ,@forms))))))
              (setf (getf plist :propspec) propspec)
-             (propappattrs (eval-propspec propspec))))))
+             (propapp-attrs (eval-propspec propspec))))))
 
 (defmacro defproplist (name type lambda &body properties)
   "Like DEFPROPSPEC, but define the function which yields the propspec using the
@@ -520,8 +517,14 @@ Called by property :HOSTATTRS, :APPLY and :UNAPPLY subroutines."
 (defun get-parent-hostattrs-car (k &optional (host *host*))
   (car (get-parent-hostattrs k host)))
 
-(defun push-hostattrs (k &rest vs)
-  "Push new static informational attributes VS of type KEY.
+(defun push-hostattr (k v)
+  "Push new static informational attribute V of type K.
+
+Called by property :HOSTATTRS subroutines."
+  (push v (getf (slot-value *host* 'hostattrs) k)))
+
+(defun push-hostattrs (k vs)
+  "Push new static informational attributes VS of type K.
 
 Called by property :HOSTATTRS subroutines."
   (setf (getf (slot-value *host* 'hostattrs) k)
@@ -575,30 +578,28 @@ the actual state of the host but without making any changes.
 
 Not to be confused with INAPPLICABLE-PROPERTY.")
 
-(defun maybe-writefile-string (path content &key (mode nil mode-supplied-p))
-  "Wrapper around WRITEFILE which returns :NO-CHANGE and avoids writing PATH if
-PATH already has the specified CONTENT and MODE."
+(defun maybe-write-remote-file-string
+    (path content &key (mode nil mode-supplied-p))
+  "Wrapper around WRITE-REMOTE-FILE which returns :NO-CHANGE and avoids writing
+PATH if PATH already has the specified CONTENT and MODE."
   (if (and (remote-exists-p path)
            (multiple-value-bind (existing-mode existing-size)
                (remote-file-stats path)
              (and (or (not mode-supplied-p) (= mode existing-mode))
                   (and (>= (* 4 (length content)) existing-size)
-                       (string= (readfile path) content)))))
+                       (string= (read-remote-file path) content)))))
       :no-change
-      (apply #'writefile
+      (apply #'write-remote-file
              path content (and mode-supplied-p `(:mode ,mode)))))
 
-(defun call-with-os (f &rest args)
-  (apply (ensure-function f) (get-hostattrs-car :os) args))
-
-(defun assert-euid-root ()
+(defun assert-remote-euid-root ()
   "Assert that the remote user has uid 0 (root)"
   (unless (zerop (get-connattr :remote-uid))
-    (failed-change "Property requires root to apply")))
+    (aborted-change "Property requires root to apply")))
 
 (defun assert-connection-supports (type)
   (unless (or (eq type :posix) (lisp-connection-p))
-    (failed-change
+    (aborted-change
      "Cannot apply :LISP properties using a POSIX-type connection")))
 
 (defun cksum (file)
