@@ -1,6 +1,6 @@
 ;;; Consfigurator -- Lisp declarative configuration management system
 
-;;; Copyright (C) 2021  Sean Whitton <spwhitton@spwhitton.name>
+;;; Copyright (C) 2021-2022  Sean Whitton <spwhitton@spwhitton.name>
 
 ;;; This file is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -23,20 +23,20 @@
   (:check
    (declare (ignore options host))
    ;; check whether a previous debootstrap failed partway through
-   (if (test "-d" (merge-pathnames "debootstrap/"
-                                   (ensure-directory-pathname root)))
+   (if (remote-test "-d" (merge-pathnames "debootstrap/"
+                                          (ensure-directory-pathname root)))
        (progn (delete-remote-trees root) nil)
        (remote-exists-p (chroot-pathname "/usr/lib/os-release" root))))
   (:apply
    (destructuring-bind
        (&key (apt.proxy (get-hostattrs-car :apt.proxy host))
-          (apt.mirror (get-hostattrs-car :apt.mirror host))
+          (apt.mirror (get-hostattrs-car :apt.mirrors host))
         &allow-other-keys
         &aux (os (get-hostattrs-car :os host))
           (args (list "debootstrap"
-                      (plist-to-cmd-args
-                       (remove-from-plist options :apt.proxy :apt.mirror))
-                      (strcat "--arch=" (os:debian-architecture os))
+                      (plist-to-long-options
+                       (remove-from-plist options :apt.proxy :apt.mirrors))
+                      (strcat "--arch=" (os:debian-architecture-string os))
                       (os:debian-suite os)
                       root)))
        options
@@ -72,9 +72,11 @@
         ;; %DEBOOTSTRAP-MANUALLY-INSTALLED for the case where the
         ;; architectures do not match because ensuring that debootstrap(8)
         ;; will be able to bootstrap a foreign arch is more involved.
-        ,@(and (not (call-with-os
-                     #'os:supports-arch-p
-                     (os:linux-architecture (get-hostattrs-car :os host))))
+        ,@(and (compute-applicable-methods
+                #'os:supports-arch-p
+                (list (get-hostattrs-car :os) (get-hostattrs-car :os host)))
+               (not (os:supports-arch-p
+                     (get-hostattrs-car :os) (get-hostattrs-car :os host)))
                '((os:etypecase
                    (debianlike (apt:installed "qemu-user-static")))))))))
 
