@@ -30,11 +30,11 @@
   `(setq ,uid-maps-param
          (or ,uid-maps-param
              (list (cons 0 (multiple-value-list
-                            (get-ids-offset user "/etc/subuid")))))
+                            (get-ids-offset "/etc/subuid" user)))))
          ,gid-maps-param
          (or ,gid-maps-param
              (list (cons 0 (multiple-value-list
-                            (get-ids-offset user "/etc/subgid")))))))
+                            (get-ids-offset "/etc/subgid" user)))))))
 
 (defprop user-container-started :posix (host &optional owner)
   "Ensure the LXC unprivileged container for the host designated by HOST owned
@@ -56,13 +56,13 @@ and owned by OWNER, defaulting to the current user, is already started."
     when-user-container-running* (host owner propapp)
   (macrolet ((check-running (form)
                `(if (user-container-running-p host owner) ,form :no-change)))
-    (:retprop :type (propapptype propapp)
+    (:retprop :type (propapp-type propapp)
               :desc (get (car propapp) 'desc)
               :hostattrs (get (car propapp) 'hostattrs)
               :apply (lambda-ignoring-args
-                       (check-running (propappapply propapp)))
+                       (check-running (apply-propapp propapp)))
               :unapply (lambda-ignoring-args
-                         (check-running (propappunapply propapp)))
+                         (check-running (unapply-propapp propapp)))
               :args (cdr propapp))))
 
 (defproplist user-containers-autostart :posix (user)
@@ -89,9 +89,9 @@ is ~/.config."
 
         "[Install]"
         "WantedBy=default.target"))
-    (systemd:enabled "lxc-autostart" t)))
+    (systemd:enabled "lxc-autostart" :user-instance t)))
 
-(defprop usernet-usable-by :posix
+(defprop usernet-veth-usable-by :posix
     (user &optional (interface "lxcbr0") (count 10))
   "Ensure that USER is allowed to attach up to COUNT unprivileged LXCs to the
 LXC-managed bridge INTERFACE.
@@ -100,7 +100,7 @@ As a special case, INTERFACE may also be \"none\", which gives USER permission
 to create veth pairs where the peer outside the container is not attached to
 any bridge."
   (:desc #?"${user} may attach LXC veth devices to ${interface}")
-  (:apply (file:map-file-lines
+  (:apply (file:map-remote-file-lines
            "/etc/lxc/lxc-usernet"
            (lambda (lines)
              (loop with done
@@ -198,8 +198,8 @@ OPTIONS is a plist of keyword parameters:
     lxc.container.conf(5).  In most cases you will need to include, at a
     minimum, lines setting up a network interface for the container.  The
     default value serves as an example of a standard way to do this; if you
-    use them unmodified, you will also need to apply LXC:USERNET-USABLE-BY for
-    USER before this property.
+    use them unmodified, you will also need to apply
+    LXC:USERNET-VETH-USABLE-BY for USER before this property.
 
   - :UID-MAPS -- a list of the form (INSIDE OUTSIDE COUNT), or a list of such
     lists, specifying the subordinate UIDs for the container's user namespace.
@@ -309,7 +309,7 @@ implications."
   (let* ((runuser
            (and owner (not (string= owner (get-connattr :remote-user)))))
          (uid (if runuser
-                  (user:passwd-entry 2 owner)
+                  (user:passwd-field 2 owner)
                   (get-connattr :remote-uid))))
     (apply #'run :env `(:DBUS_SESSION_BUS_ADDRESS nil
                         :XDG_RUNTIME_DIR ,(format nil "/run/user/~D" uid))
@@ -321,8 +321,8 @@ implications."
 
 (defun user-container-active-p (host &optional owner)
   (and (not (service:no-services-p))
-       (memstring= (get-hostname host) (lxc-ls owner "--active"))))
+       (memstr= (get-hostname host) (lxc-ls owner "--active"))))
 
 (defun user-container-running-p (host &optional owner)
   (and (not (service:no-services-p))
-       (memstring= (get-hostname host) (lxc-ls owner "--running"))))
+       (memstr= (get-hostname host) (lxc-ls owner "--running"))))
